aboutsummaryrefslogtreecommitdiff
path: root/src/libjin/Graphics/je_texture.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/libjin/Graphics/je_texture.cpp')
-rw-r--r--src/libjin/Graphics/je_texture.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/libjin/Graphics/je_texture.cpp b/src/libjin/Graphics/je_texture.cpp
index d2e53e2..da56047 100644
--- a/src/libjin/Graphics/je_texture.cpp
+++ b/src/libjin/Graphics/je_texture.cpp
@@ -8,12 +8,12 @@
#include "je_texture.h"
-namespace jin
+namespace JinEngine
{
- namespace graphics
+ namespace Graphics
{
- using namespace jin::math;
+ using namespace JinEngine::Math;
/*static*/ Texture* Texture::createTexture(Bitmap* bitmap)
{
@@ -30,7 +30,7 @@ namespace jin
{
}
- } // namespace graphics
-} // namespace jin
+ } // namespace Graphics
+} // namespace JinEngine
#endif // LIBJIN_MODULES_RENDER \ No newline at end of file